@@ -35,8 +35,8 @@ import com.biglybt.core.util.protocol.AzURLStreamHandlerFactory;
 public class
 COConfigurationManager
 {
-	public static final int CONFIG_DEFAULT_MIN_MAX_UPLOAD_SPEED			= 5;
-	public static final int CONFIG_DEFAULT_MAX_DOWNLOAD_SPEED			= 0;
+	public static final long CONFIG_DEFAULT_MIN_MAX_UPLOAD_SPEED		= 5;
+	public static final long CONFIG_DEFAULT_MAX_DOWNLOAD_SPEED			= 0;
 	public static final int	CONFIG_DEFAULT_MAX_CONNECTIONS_PER_TORRENT	= 50;
 	public static final int	CONFIG_DEFAULT_MAX_CONNECTIONS_GLOBAL		= 250;
 
@@ -57,6 +57,7 @@ COConfigurationManager
 	public static final int	MAX_DATA_SOCKS_PROXIES = 3;
 	
 	private static boolean	pre_initialised;
+	private static boolean	pre_initialising;
 
 	public static synchronized void
 	preInitialise()
@@ -66,6 +67,8 @@ COConfigurationManager
 			pre_initialised	= true;
 
 			try{
+				pre_initialising = true;
+				
 				if ( System.getProperty(SystemProperties.SYSPROP_PORTABLE_ENABLE, "false" ).equalsIgnoreCase( "true" )){
 
 					try{
@@ -233,16 +236,16 @@ COConfigurationManager
 				if ( Constants.isJava9OrHigher ){
 					
 					try{
-						if ( Constants.isJava12OrHigher ){
-							
-								// AENameServiceJava12.init();
-							
+						if ( Constants.isJava18OrHigher ){
+													
+							Class.forName( "com.biglybt.core.util.spi.AENameServiceJava18").getMethod( "init" ).invoke( null );
+
+						}else if ( Constants.isJava12OrHigher ){
+														
 							Class.forName( "com.biglybt.core.util.spi.AENameServiceJava12").getMethod( "init" ).invoke( null );
 							
 						}else{
-							
-								// AENameServiceJava9.init();
-							
+								
 							Class.forName( "com.biglybt.core.util.spi.AENameServiceJava9").getMethod( "init" ).invoke( null );
 						}
 					}catch( Throwable e ){
@@ -261,7 +264,14 @@ COConfigurationManager
 			}catch( Throwable e ){
 
 				e.printStackTrace();
+				
+			}finally{
+				
+				pre_initialising = false;
 			}
+		}else if ( pre_initialising ){
+			
+			new Exception( "Recursion during pre-init" ).printStackTrace();
 		}
 	}
 
