@@ -133,12 +133,13 @@ DiskManagerFactory
 
 	public static void
 	deleteDataFiles(
-		TOTorrent 	torrent,
-		String		torrent_save_dir,
-		String		torrent_save_file,
-		boolean		force_no_recycle )
+		DownloadManager	dm,
+		TOTorrent 		torrent,
+		String			torrent_save_dir,
+		String			torrent_save_file,
+		boolean			force_no_recycle )
 	{
-	  DiskManagerImpl.deleteDataFiles(torrent, torrent_save_dir, torrent_save_file, force_no_recycle );
+	  DiskManagerImpl.deleteDataFiles( dm, torrent, torrent_save_dir, torrent_save_file, force_no_recycle );
 	}
 
 	public static DiskManagerFileInfoSet
@@ -149,14 +150,6 @@ DiskManagerFactory
 		return( DiskManagerUtil.getFileInfoSkeleton( download_manager, listener ));
 	}
 
-	public static void
-	setFileLinks(
-		DownloadManager			download_manager,
-		LinkFileMap				links )
-	{
-		DiskManagerImpl.setFileLinks( download_manager, links );
-	}
-
 	public static void
 	clearResumeData(
 		DownloadManager			download_manager,
