@@ -416,6 +416,18 @@ DownloadManagerController
 
 		download_manager.informWillBeStarted( temp );
 
+		if (Logger.isEnabled()){
+			
+			Logger.log(
+					new LogEvent(
+						this, 
+						LogIDs.CORE, 
+						"Started - state=" + getState() +
+							" reason=" + download_manager.getStartReason()));
+			
+			download_manager.setStartReason( null );
+		}
+		
 		temp.start();
 
 		   //The connection to the tracker
@@ -542,7 +554,7 @@ DownloadManagerController
 					}
 
 					@Override
-					public int
+					public long
 					getUploadSpeedKBSec(
 						boolean estimate )
 					{
@@ -556,9 +568,9 @@ DownloadManagerController
 
 							if ( current_local == 0 ){
 
-								int current_global 	= global_stats.getDataSendRate();
+								long current_global 	= global_stats.getDataSendRate();
 
-								int	old_global		= global_stats.getDataSendRateAtClose();
+								long	old_global		= global_stats.getDataSendRateAtClose();
 
 								if ( current_global < old_global ){
 
@@ -1215,7 +1227,15 @@ DownloadManagerController
 
 			control_mon.exit();
 
-			Logger.log(new LogEvent(this, LogIDs.CORE, "Stopped - state=" + getState() + ",error=" + getErrorType() + "/" + getErrorDetail() + "/" + getErrorFlags()));
+			Logger.log(
+				new LogEvent(
+					this, 
+					LogIDs.CORE, 
+					"Stopped - state=" + getState() +
+						" reason=" + download_manager.getStopReason() + "/" + download_manager.getQueueReason() +
+						", error=" + getErrorType() + "/" + getErrorDetail() + "/" + getErrorFlags()));
+			
+			download_manager.setQueueReason( null );
 
 			download_manager.informStateChanged();
 		}
@@ -2632,7 +2652,7 @@ DownloadManagerController
 		// by adding them to all peers as peer-limits. So for the moment we stick with global (non-lan) limits
 
 	@Override
-	public int
+	public long
 	getPermittedBytesToReceive()
 	{
 		return( NetworkManager.getSingleton().getRateHandler( false, false ).getCurrentNumBytesAllowed()[0]);
@@ -2647,7 +2667,7 @@ DownloadManagerController
 	}
 
 	@Override
-	public int
+	public long
 	getPermittedBytesToSend()
 	{
 		return( NetworkManager.getSingleton().getRateHandler( true, false ).getCurrentNumBytesAllowed()[0]);
@@ -2877,7 +2897,7 @@ DownloadManagerController
 	public void
 	protocolBytesReceived(
 		PEPeer		peer,
-		int			bytes )
+		long		bytes )
 	{
 		if ( global_stats != null ){
 
@@ -2889,7 +2909,7 @@ DownloadManagerController
 	public void
 	dataBytesReceived(
 		PEPeer		peer,
-		int			bytes )
+		long		bytes )
 	{
 		if ( global_stats != null ){
 
@@ -2901,7 +2921,7 @@ DownloadManagerController
 	public void
 	protocolBytesSent(
 		PEPeer		peer,
-		int			bytes )
+		long		bytes )
 	{
 		if ( global_stats != null ){
 
@@ -2913,7 +2933,7 @@ DownloadManagerController
 	public void
 	dataBytesSent(
 		PEPeer		peer,
-		int			bytes )
+		long		bytes )
 	{
 		if ( global_stats != null ){
 
