@@ -208,7 +208,7 @@ public class DownloadManagerDefaultPaths extends DownloadManagerMoveHandlerUtils
     		
     		File move_to = FileUtil.newFile( explicit_target );
     		
-    		if ( !move_to.exists()){
+    		if ( !FileUtil.exists( move_to )){
 
 				move_to.mkdirs();
 			}
@@ -350,7 +350,7 @@ public class DownloadManagerDefaultPaths extends DownloadManagerMoveHandlerUtils
 	
 		    			if ( move_to != null ){
 	
-		    				if ( !move_to.exists()){
+		    				if ( !FileUtil.exists( move_to )){
 	
 		    					move_to.mkdirs();
 		    				}
@@ -678,7 +678,7 @@ public class DownloadManagerDefaultPaths extends DownloadManagerMoveHandlerUtils
 		}
 
 		public boolean checkDefaultDir(File location, File[] default_dirs) {
-			location = FileUtil.canonise(location);
+			location = FileUtil.getCanonicalFile(location);
 			boolean subdir = this.getBoolean("default subdir", false);
 			for (int i=0; i<default_dirs.length; i++) {
 				if (subdir) {
@@ -811,7 +811,7 @@ public class DownloadManagerDefaultPaths extends DownloadManagerMoveHandlerUtils
 
 						torrent_target = temp;
 
-					}else if ( !temp.exists()){
+					}else if ( !FileUtil.exists( temp )){
 
 						if ( temp.mkdirs()){
 
