@@ -56,6 +56,7 @@ import com.biglybt.core.vuzefile.VuzeFileHandler;
 import com.biglybt.core.vuzefile.VuzeFileProcessor;
 import com.biglybt.core.xml.util.XMLEscapeWriter;
 import com.biglybt.core.xml.util.XUXmlWriter;
+import com.biglybt.pif.PluginAdapter;
 import com.biglybt.pif.PluginInterface;
 import com.biglybt.pif.PluginManager;
 import com.biglybt.pif.disk.DiskManagerFileInfo;
@@ -897,7 +898,37 @@ TagManagerImpl
 				started(
 					Core core )
 				{
-					core.getPluginManager().getDefaultPluginInterface().getDownloadManager().getGlobalDownloadEventNotifier().addCompletionListener( TagManagerImpl.this);
+					PluginInterface pi = core.getPluginManager().getDefaultPluginInterface();
+					
+					pi.getDownloadManager().getGlobalDownloadEventNotifier().addCompletionListener( TagManagerImpl.this);
+					
+					pi.addListener(
+						new PluginAdapter()
+						{
+							@Override
+							public void 
+							initializationComplete()
+							{
+								SimpleTimer.addPeriodicEvent(
+										"TM:Sync",
+										30*1000,
+										new TimerEventPerformer()
+										{
+											@Override
+											public void
+											perform(
+												TimerEvent event)
+											{
+												for ( TagType tt: tag_types ){
+
+													((TagTypeBase)tt).sync();
+												}
+												
+												auto_tracker.sync();
+											}
+										});
+							}
+						});
 				}
 
 				@Override
@@ -1007,7 +1038,9 @@ TagManagerImpl
 
 									TagFeatureFileLocation tag = TagUtils.selectInitialDownloadLocation(tags);
 
-									if ( tag != null ){
+									boolean is_md = manager.getDownloadState().getFlag( DownloadManagerState.FLAG_METADATA_DOWNLOAD );
+
+									if ( tag != null && !is_md ){
 										
 										long	options = tag.getTagInitialSaveOptions();
 
@@ -1067,25 +1100,6 @@ TagManagerImpl
 					destroy();
 				}
 			});
-
-		SimpleTimer.addPeriodicEvent(
-			"TM:Sync",
-			30*1000,
-			new TimerEventPerformer()
-			{
-				@Override
-				public void
-				perform(
-					TimerEvent event)
-				{
-					for ( TagType tt: tag_types ){
-
-						((TagTypeBase)tt).sync();
-					}
-					
-					auto_tracker.sync();
-				}
-			});
 	}
 
 	@Override
@@ -1711,10 +1725,21 @@ TagManagerImpl
 		Tag			tag,
 		Taggable	tagged )
 	{
+		tagged.updateTagMutationCount();
+		
 		int tt = tag_type.getTagType();
 
 		if ( tt == TagType.TT_DOWNLOAD_MANUAL && tagged instanceof DownloadManager ){
 
+			DownloadManager dm = (DownloadManager)tagged;
+
+			boolean is_md = dm.getDownloadState().getFlag( DownloadManagerState.FLAG_METADATA_DOWNLOAD );
+			
+			if ( is_md ){
+				
+				return;
+			}
+			
 			TagFeatureFileLocation fl = (TagFeatureFileLocation)tag;
 			
 				// hack to support initial-save-location logic when a user manually assigns a tag and the download
@@ -1727,8 +1752,6 @@ TagManagerImpl
 
 					if ( save_loc != null ){
 
-						DownloadManager dm = (DownloadManager)tagged;
-
 						if ( dm.getState() == DownloadManager.STATE_STOPPED ){
 
 							TOTorrent torrent = dm.getTorrent();
@@ -1789,9 +1812,7 @@ TagManagerImpl
 					File ass_loc = fl.getTagMoveOnAssignFolder();
 		
 					if ( ass_loc != null ){
-		
-						DownloadManager dm = (DownloadManager)tagged;
-		
+				
 						TOTorrent torrent = dm.getTorrent();
 	
 						if ( torrent != null ){
@@ -1895,6 +1916,8 @@ TagManagerImpl
 		Tag			tag,
 		Taggable	tagged )
 	{
+		tagged.updateTagMutationCount();
+		
 		int tt = tag_type.getTagType();
 
 			// as above
