@@ -99,7 +99,7 @@ TOTorrentImpl
 	private int								torrent_type;
 	
 	private byte[]							torrent_name;
-	private byte[]							torrent_name_utf8;
+	private String							torrent_name_utf8;
 
 	private byte[]							comment;
 	private URL								announce_url;
@@ -164,7 +164,8 @@ TOTorrentImpl
 		created	= true;
 
 		torrent_name = _torrent_name.getBytes(Constants.DEFAULT_ENCODING_CHARSET);
-		torrent_name_utf8 = torrent_name;
+		
+		torrent_name_utf8 = _torrent_name;
 
 		setAnnounceURL(_announce_url);
 		
@@ -192,12 +193,18 @@ TOTorrentImpl
 									
 				// defer until needed
 				// TOTorrentCreateV2Impl.setV2FileHashes( this );
-			}
-				
+			}	
 		}finally{
 		
 			constructing = false;
 		}
+		
+		if ( created ){
+
+				// register here, may change later but it will be re-registered then
+			
+			TorrentUtils.addCreatedTorrent( this );
+		}
 	}
 	
 	protected void
@@ -581,7 +588,7 @@ TOTorrentImpl
 
 		if ( torrent_name_utf8 != null ){
 
-			info.put( TK_NAME_UTF8, torrent_name_utf8 );
+			info.put( TK_NAME_UTF8, torrent_name_utf8.getBytes( Constants.UTF_8 ));
 		}
 
 		if ( torrent_hash_override != null ){
@@ -724,19 +731,17 @@ TOTorrentImpl
 	public String
 	getUTF8Name()
 	{
-		try {
-			return torrent_name_utf8 == null ? null : new String(torrent_name_utf8,
-					"utf8");
-		} catch (UnsupportedEncodingException e) {
-			return null;
-		}
+		return( torrent_name_utf8 );
 	}
 
 	protected void
 	setNameUTF8(
-		byte[]	_name )
+		byte[]	name )
 	{
-		torrent_name_utf8	= _name;
+		if ( name != null ){ 
+		
+			torrent_name_utf8 = new String ( name, Constants.UTF_8 );
+		}
 	}
 
 	@Override
@@ -782,7 +787,7 @@ TOTorrentImpl
 	setAnnounceURL(
 		URL		url )
 	{
-		URL newURL = anonymityTransform( url );
+		URL newURL = url;
 		String s0 = (newURL == null) ? "" : newURL.toString();
 		String s1 = (announce_url == null) ? "" : announce_url.toString();
 		if (s0.equals(s1))
@@ -855,13 +860,6 @@ TOTorrentImpl
 		return( created_by );
 	}
 
-	@Override
-	public boolean
-	isCreated()
-	{
-		return( created );
-	}
-
 	@Override
 	public byte[]
 	getHash()
@@ -1043,7 +1041,7 @@ TOTorrentImpl
 			throw( new TOTorrentException( 	"Torrent isn't hybrid", TOTorrentException.RT_CREATE_FAILED ));
 		}
 		
-		TOTorrent clone = TOTorrentFactory.deserialiseFromBEncodedByteArray( serialiseToByteArray());
+		TOTorrent clone = TOTorrentFactory.deserialiseFromBEncodedByteArray( new TOTorrentFactory.TorrentDataHolder( serialiseToByteArray()));
 
 		TorrentUtils.clearTorrentFileName( clone );
 		
@@ -1070,7 +1068,7 @@ TOTorrentImpl
 		try{
 				// recreate with new properties so result represents this
 			
-			return( TOTorrentFactory.deserialiseFromBEncodedByteArray( BEncoder.encode( clone.serialiseToMap())));
+			return( TOTorrentFactory.deserialiseFromBEncodedByteArray( new TOTorrentFactory.TorrentDataHolder( BEncoder.encode( clone.serialiseToMap()))));
 			
 		}catch( Throwable e ){
 			
@@ -1120,7 +1118,7 @@ TOTorrentImpl
 		throws TOTorrentException
 	{
 		
-		TOTorrent clone = TOTorrentFactory.deserialiseFromBEncodedByteArray( serialiseToByteArray());
+		TOTorrent clone = TOTorrentFactory.deserialiseFromBEncodedByteArray( new TOTorrentFactory.TorrentDataHolder( serialiseToByteArray()));
 
 		TorrentUtils.clearTorrentFileName( clone );
 		
@@ -1162,7 +1160,7 @@ TOTorrentImpl
 		try{
 				// recreate with new properties so result represents this
 			
-			return( TOTorrentFactory.deserialiseFromBEncodedByteArray( BEncoder.encode( clone.serialiseToMap())));
+			return( TOTorrentFactory.deserialiseFromBEncodedByteArray( new TOTorrentFactory.TorrentDataHolder( BEncoder.encode( clone.serialiseToMap()))));
 			
 		}catch( Throwable e ){
 			
@@ -1273,7 +1271,7 @@ TOTorrentImpl
 	addTorrentAnnounceURLSet(
 		URL[]		urls )
 	{
-		announce_group.addSet( new TOTorrentAnnounceURLSetImpl( this, urls ));
+		announce_group.addSet( announce_group.createAnnounceURLSet( urls ));
 	}
 
 	@Override
@@ -1601,42 +1599,6 @@ TOTorrentImpl
 		return value.getBytes(Constants.DEFAULT_ENCODING_CHARSET);
 	}
 
-	protected URL
-	anonymityTransform(
-		URL		url )
-	{
-		/*
-		 * 	hmm, doing this is harder than it looks as we have issues hosting
-		 *  (both starting tracker instances and also short-cut loopback for seeding
-		 *  leave as is for the moment
-		if ( HostNameToIPResolver.isNonDNSName( url.getHost())){
-
-			// remove the port as it is uninteresting and could leak information about the
-			// tracker
-
-			String	url_string = url.toString();
-
-			String	port_string = ":" + (url.getPort()==-1?url.getDefaultPort():url.getPort());
-
-			int	port_pos = url_string.indexOf( ":" + url.getPort());
-
-			if ( port_pos != -1 ){
-
-				try{
-
-					return( new URL( url_string.substring(0,port_pos) + url_string.substring(port_pos+port_string.length())));
-
-				}catch( MalformedURLException e){
-
-					Debug.printStackTrace(e);
-				}
-			}
-		}
-		*/
-
-		return( url );
-	}
-
 	@Override
 	public void
 	print()
