@@ -459,6 +459,8 @@ public class TrackerStatus {
 
 			List<TRTrackerScraperResponseImpl> activeResponses = responsesInQuery;
 
+			URL reqUrl = null;
+			
 			try {
 				// if URL already includes a query component then just append our
 				// params
@@ -569,7 +571,7 @@ public class TrackerStatus {
 					request += "&azsf=" + flags + "&azver=" + TRTrackerAnnouncer.AZ_TRACKER_VERSION_CURRENT;
 				}
 
-				URL reqUrl = new URL( request );
+				reqUrl = new URL( request );
 
 				if (Logger.isEnabled())
 					Logger.log(new LogEvent(LOGID,
@@ -663,7 +665,15 @@ public class TrackerStatus {
 
 			  			activeResponses = responsesInQuery;
 
-			  			redirect_url = scrapeHTTP(hashesInQuery,reqUrl, message);
+			  			URL[] _reqUrl = { reqUrl };
+			  			
+			  			try{
+			  				redirect_url = scrapeHTTP(hashesInQuery,_reqUrl, message);
+			  				
+			  			}finally{
+			  			
+			  				reqUrl = _reqUrl[0];
+			  			}
 			  		}
 				}finally{
 
@@ -1013,15 +1023,15 @@ public class TrackerStatus {
 					scraper.scrapeReceived(response);
 				}
 			} catch (SocketException e) {
-				setAllError(activeResponses,e);
+				setAllError(reqUrl,activeResponses,e);
 			} catch (SocketTimeoutException e) {
-				setAllError(activeResponses,e);
+				setAllError(reqUrl,activeResponses,e);
 			} catch (UnknownHostException e) {
-				setAllError(activeResponses,e);
+				setAllError(reqUrl,activeResponses,e);
 			} catch (PRUDPPacketHandlerException e) {
-				setAllError(activeResponses,e);
+				setAllError(reqUrl,activeResponses,e);
 			} catch (BEncodingException e) {
-				setAllError(activeResponses,e);
+				setAllError(reqUrl,activeResponses,e);
 			} catch (Exception e) {
 
 				// for apache we can get error 414 - URL too long. simplest solution
@@ -1038,7 +1048,7 @@ public class TrackerStatus {
 							|| error_message.contains(" 501 ")) {
 						// various errors that have a 99% chance of happening on
 						// any other scrape request
-						setAllError(activeResponses,e);
+						setAllError(reqUrl,activeResponses,e);
 						return;
 					}
 
@@ -1072,9 +1082,10 @@ public class TrackerStatus {
 
 					if (Logger.isEnabled()) {
 						HashWrapper hash = response.getHash();
+						
 						Logger.log(new LogEvent(TorrentUtils.getDownloadManager(hash), LOGID,
-								LogEvent.LT_ERROR, "Error from scrape interface " + scrapeURL
-										+ " : " + msg + " (" + e.getClass() + ")"));
+								LogEvent.LT_ERROR, formatScrapeErrorMessage( reqUrl, msg ))); 
+								
 					}
 
 					response.setNextScrapeStartTime(SystemTime.getCurrentTime()
@@ -1094,10 +1105,22 @@ public class TrackerStatus {
 		}
 	}
 
-  /**
-	 * @param e
-	 */
-	private void setAllError(List<TRTrackerScraperResponseImpl> responses, Exception e) {
+  	private String
+  	formatScrapeErrorMessage(
+  		URL			reqURL, 
+  		String		msg )
+  	{
+		if ( reqURL != null ){
+			
+				// tidy up message to remove any loopback bind mods
+			
+			msg = msg.replace(reqURL.toExternalForm(),scrapeURL);
+		}
+		
+  		return( "Error from scrape interface " + scrapeURL + " : " + msg );
+  	}
+  	
+	private void setAllError(URL reqURL, List<TRTrackerScraperResponseImpl> responses, Exception e) {
 
 		String msg;
 
@@ -1123,8 +1146,7 @@ public class TrackerStatus {
 			if (Logger.isEnabled()) {
 				HashWrapper hash = response.getHash();
 				Logger.log(new LogEvent(TorrentUtils.getDownloadManager(hash), LOGID,
-						LogEvent.LT_WARNING, "Error from scrape interface " + scrapeURL
-								+ " : " + msg));
+						LogEvent.LT_WARNING, formatScrapeErrorMessage( reqURL, msg )));
 				//e.printStackTrace();
 			}
 
@@ -1140,15 +1162,17 @@ public class TrackerStatus {
 	private URL
  	scrapeHTTP(
  		List<HashWrapper>		hashesInQuery,
- 		URL 					reqUrl,
+ 		URL[] 					_reqUrl,
  		ByteArrayOutputStream 	message )
 
  		throws Exception
  	{
+		URL reqUrl = _reqUrl[0];
+				
 		byte[]	example_hash = hashesInQuery.get(0).getBytes();
 
 		try{
-			return( scrapeHTTPSupport( reqUrl, example_hash, null, message ));
+			return( scrapeHTTPSupport( _reqUrl, example_hash, null, message ));
 
 		}catch( Exception e ){
 
@@ -1235,7 +1259,7 @@ public class TrackerStatus {
 
 					try{
 
-						URL result =  scrapeHTTPSupport( proxy.getURL(), example_hash, proxy.getProxy(), message );
+						URL result =  scrapeHTTPSupport( new URL[]{ proxy.getURL()}, example_hash, proxy.getProxy(), message );
 
 						ok = true;
 
@@ -1257,7 +1281,7 @@ public class TrackerStatus {
 
 	private URL
 	scrapeHTTPSupport(
-		URL 					reqUrl,
+		URL[] 					_reqUrl,
 		byte[]					example_hash,
 		Proxy					proxy,
 		ByteArrayOutputStream 	message )
@@ -1270,6 +1294,8 @@ public class TrackerStatus {
 
 			URL	redirect_url = null;
 
+			URL reqUrl = _reqUrl[0];
+			
 			TRTrackerUtils.checkForBlacklistedURLs( reqUrl );
 
 			reqUrl = TRTrackerUtils.adjustURLForHosting( reqUrl );
@@ -1302,6 +1328,8 @@ public class TrackerStatus {
 
 			reqUrl = (URL)http_properties.get( ClientIDGenerator.PR_URL );
 
+			_reqUrl[0] = reqUrl;
+			
 			InputStream is = null;
 
 			try{
@@ -1472,11 +1500,11 @@ public class TrackerStatus {
 						}
 					} catch (Exception e) {
 
-						if (Logger.isEnabled())
-							Logger.log(new LogEvent(LOGID, LogEvent.LT_ERROR,
-									"Error from scrape interface " + scrapeURL + " : "
-									+ Debug.getNestedExceptionMessage(e)));
-
+						if (Logger.isEnabled()){
+							String msg = Debug.getNestedExceptionMessage(e);
+							Logger.log(new LogEvent(LOGID, LogEvent.LT_ERROR,formatScrapeErrorMessage( reqUrl, msg )));
+						}
+						
 						return( null );
 					}
 				}
@@ -1557,7 +1585,7 @@ public class TrackerStatus {
   scrapeUDP(
 		URL reqUrl, 
 		ByteArrayOutputStream message, 
-		List hashes, 
+		List<HashWrapper> hashesInQuery, 
 		boolean do_auth_test )
 				
 		throws Throwable 
@@ -1619,6 +1647,15 @@ public class TrackerStatus {
 
 		boolean all_skipped = true;
 
+		long timeout = PRUDPPacket.DEFAULT_UDP_TIMEOUT;
+
+ 	    String	tracker_network			= AENetworkClassifier.categoriseAddress( reqUrl.getHost());
+
+ 		if ( tracker_network != AENetworkClassifier.AT_PUBLIC ){
+ 			
+ 			timeout *= 2;
+ 		}
+		
 		for ( InetSocketAddress destination: url_addresses ){
 
 			if ( destination.getAddress() instanceof Inet6Address && !ipv6_enabled ){
@@ -1628,10 +1665,86 @@ public class TrackerStatus {
 			
 			all_skipped = false;
 			
+			String[] networks = null;
+			
+			if ( tracker_network != AENetworkClassifier.AT_PUBLIC ){
+
+				if ( hashesInQuery.size() == 1 ){
+
+					networks = scraper.getEnabledNetworks( hashesInQuery.get(0));
+
+				}else{
+
+					String[] current_nets = null;
+
+					for ( HashWrapper hash: hashesInQuery ){
+
+						String[] nets = scraper.getEnabledNetworks( hash );
+
+						if ( nets == null ){
+
+							nets = new String[0];
+						}
+
+						if ( current_nets == null ){
+
+							current_nets = nets;
+
+						}else{
+
+							boolean	ok = false;
+
+							if ( nets.length == current_nets.length ){
+
+								ok = true;
+
+								for ( String net1: nets ){
+
+									boolean match = false;
+
+									for ( String net2: current_nets ){
+
+										if ( net1 == net2 ){
+
+											match = true;
+
+											break;
+										}
+									}
+
+									if ( !match ){
+
+										ok = false;
+
+										break;
+									}
+								}
+							}else{
+
+								ok = false;
+
+							}
+
+							if ( !ok ){
+
+								bSingleHashScrapes = true;
+
+								throw( new Exception( "Mixed networks, forcing single-hash scrapes" ));
+							}
+						}
+					}
+
+					if ( current_nets != null ){
+
+						networks = current_nets;
+					}
+				}
+			}
+			
 			try{
 				PRUDPPacketHandler handler = PRUDPPacketHandlerFactory.getHandler( handler_port );
 
-				handler = handler.openSession( destination );
+				handler = handler.openSession( destination, networks, "Tracker scrape" );
 
 				try{
 					String	failure_reason = null;
@@ -1641,7 +1754,7 @@ public class TrackerStatus {
 						try{
 							PRUDPPacket connect_request = new PRUDPPacketRequestConnect();
 
-							PRUDPPacket reply = handler.sendAndReceive( auth, connect_request, destination );
+							PRUDPPacket reply = handler.sendAndReceive( auth, connect_request, destination, timeout );
 
 							if ( reply.getAction() == PRUDPPacketTracker.ACT_REPLY_CONNECT ){
 
@@ -1649,7 +1762,7 @@ public class TrackerStatus {
 
 								long	my_connection = connect_reply.getConnectionId();
 
-								PRUDPPacketRequestScrape scrape_request = new PRUDPPacketRequestScrape( my_connection, hashes );
+								PRUDPPacketRequestScrape scrape_request = new PRUDPPacketRequestScrape( my_connection, hashesInQuery );
 
 								reply = handler.sendAndReceive( auth, scrape_request, destination );
 
@@ -1714,7 +1827,7 @@ public class TrackerStatus {
 										int[]		incomplete 	= scrape_reply.getIncomplete();
 
 										int i=0;
-										for(Iterator it = hashes.iterator();it.hasNext() && i < complete.length;i++)
+										for(Iterator it = hashesInQuery.iterator();it.hasNext() && i < complete.length;i++)
 										{
 											HashWrapper hash = (HashWrapper)it.next();
 											Map file = new HashMap();
@@ -1755,7 +1868,7 @@ public class TrackerStatus {
 
 						}catch( PRUDPPacketHandlerException e ){
 
-							if ( e.getMessage() == null || !e.getMessage().contains("timed out")){
+							if ( e.getMessage() == null || !Debug.getNestedExceptionMessage(e).contains("timed out")){
 
 								throw( e );
 							}
