@@ -35,6 +35,7 @@ import com.biglybt.core.config.ParameterListener;
 
 public class
 ThreadPool<T extends AERunnable>
+	implements ThreadPoolParent<T>
 {
 	private static final boolean	NAME_THREADS = Constants.IS_CVS_VERSION && System.getProperty( "az.thread.pool.naming.enable", "true" ).equals( "true" );
 
@@ -83,11 +84,11 @@ ThreadPool<T extends AERunnable>
 		}
 	}
 
-	static final ThreadLocal		tls	=
-		new ThreadLocal()
+	static final ThreadLocal<ThreadPoolTask.Worker>		tls	=
+		new ThreadLocal<ThreadPoolTask.Worker>()
 		{
 			@Override
-			public Object
+			public ThreadPoolTask.Worker
 			initialValue()
 			{
 				return( null );
@@ -208,6 +209,21 @@ ThreadPool<T extends AERunnable>
 		}
 	}
 
+	public void 
+	runTask(T runnable) 
+	{
+		run(runnable, false, false);
+	}
+	
+	public void 
+	runTask(
+		T 			runnable, 
+		boolean		high_priority, 
+		boolean 	manualRelease)
+	{
+		run(runnable, high_priority, manualRelease);	
+	}
+	
 	public threadPoolWorker 
 	run(T runnable) 
 	{
@@ -580,9 +596,9 @@ ThreadPool<T extends AERunnable>
 
 		synchronized( this ){
 
-			long elapsed = SystemTime.getMonotonousTime() - toRelease.worker.run_start_time;
+			long elapsed = SystemTime.getMonotonousTime() - toRelease.worker.getStartTime();
 			if (elapsed > WARN_TIME && LOG_WARNINGS)
-				DebugLight.out(toRelease.worker.getWorkerName() + ": terminated, elapsed = " + elapsed + ", state = " + toRelease.worker.state);
+				DebugLight.out(toRelease.worker.getWorkerName() + ": terminated, elapsed = " + elapsed + ", state = " + toRelease.worker.getState());
 
 			if ( !busy.remove(toRelease.worker)){
 
@@ -618,7 +634,7 @@ ThreadPool<T extends AERunnable>
 
 	}
 
-	public void registerThreadAsChild(threadPoolWorker parent)
+	public void registerThreadAsChild(ThreadPoolTask.Worker parent)
 	{
 		if(tls.get() == null || tls.get() == parent)
 			tls.set(parent);
@@ -626,7 +642,7 @@ ThreadPool<T extends AERunnable>
 			throw new IllegalStateException("another parent is already set for this thread");
 	}
 
-	public void deregisterThreadAsChild(threadPoolWorker parent)
+	public void deregisterThreadAsChild(ThreadPoolTask.Worker parent)
 	{
 		if(tls.get() == parent)
 			tls.set(null);
@@ -635,7 +651,11 @@ ThreadPool<T extends AERunnable>
 	}
 
 
-	class threadPoolWorker extends AEThread2 {
+	class 
+	threadPoolWorker 
+		extends AEThread2
+		implements ThreadPoolTask.Worker
+	{
 		private final String		worker_name;
 		private volatile T			runnable;
 		private long				run_start_time;
@@ -651,6 +671,12 @@ ThreadPool<T extends AERunnable>
 			start();
 		}
 
+		protected ThreadPool<T>
+		getOwner()
+		{
+			return( ThreadPool.this );
+		}
+		
 		@Override
 		public void run() {
 			tls.set(threadPoolWorker.this);
@@ -790,6 +816,13 @@ ThreadPool<T extends AERunnable>
 			}
 		}
 
+		@Override
+		public long 
+		getStartTime()
+		{
+			return( run_start_time );
+		}
+		
 		public void setState(String _state) {
 			//System.out.println( "state = " + _state );
 			state = _state;
@@ -799,12 +832,16 @@ ThreadPool<T extends AERunnable>
 			return (state);
 		}
 
-		protected String getWorkerName() {
+		public String getWorkerName() {
 			return (worker_name);
 		}
-
-		protected ThreadPool<T> getOwner() {
-			return (ThreadPool.this);
+		
+		@Override
+		public void 
+		releaseManual(
+			ThreadPoolTask task)
+		{
+			ThreadPool.this.releaseManual(task);
 		}
 
 		protected T getRunnable() {
