@@ -20,9 +20,17 @@
 package com.biglybt.net.udp.mc.impl;
 
 import java.net.*;
+import java.nio.ByteBuffer;
+import java.nio.channels.DatagramChannel;
+import java.nio.channels.MembershipKey;
+import java.nio.channels.MulticastChannel;
+import java.nio.channels.spi.AbstractSelectableChannel;
 import java.util.*;
 
 import com.biglybt.core.config.COConfigurationManager;
+import com.biglybt.core.config.ConfigKeys;
+import com.biglybt.core.networkmanager.VirtualAbstractChannelSelector;
+import com.biglybt.core.networkmanager.VirtualAbstractChannelSelector.VirtualSelectorListener;
 import com.biglybt.core.util.*;
 import com.biglybt.net.udp.mc.MCGroup;
 import com.biglybt.net.udp.mc.MCGroupAdapter;
@@ -42,15 +50,50 @@ MCGroupImpl
 
 	private final static int		PACKET_SIZE		= 8192;
 
-
-	private static boolean							overall_suspended;
+	private final static boolean		USE_NIO	= true;
+	
 	private static Map<String,MCGroupImpl>			singletons	= new HashMap<>();
 
 	private static AEMonitor	class_mon 	= new AEMonitor( "MCGroup:class" );
 
 	private static AsyncDispatcher		async_dispatcher = new AsyncDispatcher();
 
+	private volatile boolean	ignore_v4;
+	private volatile boolean	ignore_v6;
+	
+	{
+		COConfigurationManager.addAndFireParameterListeners(
+			new String[]{
+				ConfigKeys.Connection.BCFG_IPV_4_IGNORE_NI_ADDRESSES,
+				ConfigKeys.Connection.BCFG_IPV_6_IGNORE_NI_ADDRESSES },
+			(n)->{
+				ignore_v4 = COConfigurationManager.getBooleanParameter( ConfigKeys.Connection.BCFG_IPV_4_IGNORE_NI_ADDRESSES );
+				ignore_v6 = COConfigurationManager.getBooleanParameter( ConfigKeys.Connection.BCFG_IPV_6_IGNORE_NI_ADDRESSES );
+			});
+	}
 
+	private static VirtualAbstractChannelSelector	v4_selector = new VirtualAbstractChannelSelector( "MCGroup:v4", VirtualAbstractChannelSelector.OP_READ, false );
+	private static VirtualAbstractChannelSelector	v6_selector = new VirtualAbstractChannelSelector( "MCGroup:v6", VirtualAbstractChannelSelector.OP_READ, false );
+	
+	static{
+		if ( USE_NIO ){
+			
+			new AEThread2( "MCGroup:selector", true )
+			{
+				@Override
+				public void
+				run()
+				{
+					while( true ){
+						
+						v4_selector.select( 250 );
+						v6_selector.select( 250 );
+					}
+				}
+			}.start();
+		}
+	}
+	
 	public static MCGroupImpl
 	getSingleton(
 		MCGroupAdapter adapter,
@@ -94,7 +137,7 @@ MCGroupImpl
 					}
 				}
 
-				singleton = new MCGroupImpl( adapter, group_address, group_port, control_port, interfaces, overall_suspended );
+				singleton = new MCGroupImpl( adapter, group_address, group_port, control_port, interfaces );
 
 				if ( control_port == 0 ){
 
@@ -114,36 +157,14 @@ MCGroupImpl
 		}
 	}
 
-	public static void
-	setSuspended(
-		boolean		suspended )
-	{
-		try{
-			class_mon.enter();
+	private final MCGroupAdapter			adapter;
 
-			if ( overall_suspended == suspended ){
+	private final String					group_address_str;
+	private final int						group_port;
+	protected final InetSocketAddress 		group_address;
+	protected final boolean					ipv6;
 
-				return;
-			}
-
-			overall_suspended = suspended;
-
-			for ( MCGroupImpl group: singletons.values()){
-
-				group.setInstanceSuspended( overall_suspended );
-			}
-		}finally{
-
-			class_mon.exit();
-		}
-	}
-
-	private MCGroupAdapter			adapter;
-
-	private String					group_address_str;
-	private int						group_port;
 	private int						control_port;
-	protected InetSocketAddress 	group_address;
 	private String[]				selected_interfaces;
 
 
@@ -154,9 +175,6 @@ MCGroupImpl
 
 	private Map<String,Set<InetAddress>>		current_registrations = new HashMap<>();
 
-	private volatile boolean		instance_suspended;
-	private List<Object[]>			suspended_threads = new ArrayList<>();
-
 	private Map<String,MulticastSocket>		socket_cache = new HashMap<>();
 
 	private
@@ -165,8 +183,7 @@ MCGroupImpl
 		String				_group_address,
 		int					_group_port,
 		int					_control_port,
-		String[]			_interfaces,
-		boolean				_is_suspended )
+		String[]			_interfaces )
 
 		throws MCGroupException
 	{
@@ -177,11 +194,11 @@ MCGroupImpl
 		control_port		= _control_port;
 		selected_interfaces	= _interfaces;
 
-		instance_suspended	= _is_suspended;
-
 		try{
 			InetAddress ia = HostNameToIPResolver.syncResolve( group_address_str );
 
+			ipv6 = ia instanceof Inet6Address;
+			
 			group_address = new InetSocketAddress( ia, 0 );
 
 			processNetworkInterfaces( true );
@@ -212,63 +229,11 @@ MCGroupImpl
 		}
 	}
 
-	private void
-	setInstanceSuspended(
-		boolean	_suspended )
+	@Override
+	public boolean 
+	isIPv6()
 	{
-		try{
-			this_mon.enter();
-
-			if ( instance_suspended == _suspended ){
-
-				return;
-			}
-
-			instance_suspended = _suspended;
-
-			if ( !instance_suspended ){
-
-				List<Object[]> states = new ArrayList<>(suspended_threads);
-
-				suspended_threads.clear();
-
-				for ( final Object[] state: states ){
-
-					new AEThread2( (String)state[0], true )
-					{
-						@Override
-						public void
-						run()
-						{
-							handleSocket( (NetworkInterface)state[1], (InetAddress)state[2], (DatagramSocket)state[3], (Boolean)state[4] );
-						}
-					}.start();
-				}
-			}
-		}finally{
-
-			this_mon.exit();
-		}
-
-		if ( !_suspended ){
-
-			async_dispatcher.dispatch(
-				new AERunnable()
-				{
-					@Override
-					public void
-					runSupport()
-					{
-						try{
-							processNetworkInterfaces( false );
-
-						}catch( Throwable e ){
-
-							adapter.log( e );
-						}
-					}
-				});
-		}
+		return( ipv6 );
 	}
 
 	private void
@@ -284,11 +249,6 @@ MCGroupImpl
 		try{
 			this_mon.enter();
 
-			if ( instance_suspended ){
-
-				return;
-			}
-
 			List<NetworkInterface>	x = NetUtils.getNetworkInterfaces();
 
 			for ( final NetworkInterface network_interface: x ){
@@ -302,6 +262,11 @@ MCGroupImpl
 
 					continue;
 				}
+				
+				if ( ( ignore_v4 && !ipv6 ) || ( ignore_v6 && ipv6 )){
+					
+					continue;
+				}
 
 				String ni_name = network_interface.getName();
 
@@ -343,16 +308,20 @@ MCGroupImpl
 						continue;
 					}
 
-					if ( ni_address instanceof Inet6Address ){
-
-						if ( start_of_day ){
-
-							adapter.trace( "ignoring IPv6 address " + ni_address + ", interface " + network_interface.getName());
-						}
+					if (	ipv6 && ni_address instanceof Inet4Address ||
+							!ipv6 && ni_address instanceof Inet6Address ){
 
 						continue;
 					}
 
+					if ( ni_address instanceof Inet6Address ){
+						
+						if ( ni_address.isLinkLocalAddress()){
+							
+							continue;
+						}
+					}
+					
 					if ( !start_of_day ){
 
 						if ( !changed_interfaces.containsKey( ni_name )){
@@ -361,112 +330,208 @@ MCGroupImpl
 						}
 					}
 
-					try{
-							// set up group
-
-						final MulticastSocket mc_sock = new MulticastSocket( group_port );
-
-						mc_sock.setReuseAddress(true);
-
-							// windows 98 doesn't support setTimeToLive
-
+					if ( USE_NIO ){
+						
 						try{
-							mc_sock.setTimeToLive(TTL);
-
-						}catch( Throwable e ){
-
-							if ( !ttl_problem_reported ){
-
-								ttl_problem_reported	= true;
-
-								adapter.log( e );
+							DatagramChannel mc_channel = DatagramChannel.open( ipv6?StandardProtocolFamily.INET6:StandardProtocolFamily.INET );
+	
+							mc_channel.setOption(StandardSocketOptions.SO_REUSEADDR, true );
+							
+							try{
+								mc_channel.setOption(StandardSocketOptions.IP_MULTICAST_TTL, TTL );
+								
+							}catch( Throwable e ){
+								
+								if ( !ttl_problem_reported ){
+	
+									ttl_problem_reported	= true;
+	
+									adapter.log( e );
+								}
 							}
+							
+							mc_channel.setOption(StandardSocketOptions.IP_MULTICAST_LOOP, true );
+
+							mc_channel.setOption(StandardSocketOptions.IP_MULTICAST_IF, network_interface );
+							
+							mc_channel.bind( new InetSocketAddress( group_port ));
+								
+							adapter.trace( "group = " + group_address +"/" +
+											network_interface.getName()+":"+
+											network_interface.getDisplayName() + "-" + ni_address.getHostAddress() +": started" );
+
+							
+							MembershipKey key = mc_channel.join( group_address.getAddress(), network_interface );
+							
+							mc_channel.socket().setSoTimeout( 30*1000 );
+							
+							Runtime.getRuntime().addShutdownHook(
+									new AEThread("MCGroup:VMShutdown")
+									{
+										@Override
+										public void
+										runSupport()
+										{
+											try{
+												key.drop();
+	
+											}catch( Throwable e ){
+	
+												adapter.log( e );
+											}
+										}
+									});
+							
+							mc_channel.configureBlocking( false );
+							
+							SelectorListener listener = new SelectorListener( network_interface, ni_address, mc_channel, true );
+								
+							if ( ipv6 ){
+								
+								v6_selector.register( mc_channel, listener, null );
+								
+							}else{ 
+								
+								v4_selector.register( mc_channel, listener, null );
+							}
+						}catch( Throwable e ){
+							
+							// adapter.log( "Failed to join group '" + group_address + ", ni=" + network_interface, e );
 						}
-
-						String	addresses_string = "";
-
-						Enumeration<InetAddress> it = network_interface.getInetAddresses();
-
-						while (it.hasMoreElements()){
-
-							InetAddress addr = it.nextElement();
-
-							addresses_string += (addresses_string.length()==0?"":",") + addr;
-						}
-
-						adapter.trace( "group = " + group_address +"/" +
-										network_interface.getName()+":"+
-										network_interface.getDisplayName() + "-" + addresses_string +": started" );
-
-						mc_sock.joinGroup( group_address, network_interface );
-
-						mc_sock.setNetworkInterface( network_interface );
-
-							// note that false ENABLES loopback mode which is what we want
-
-						mc_sock.setLoopbackMode(false);
-
-						Runtime.getRuntime().addShutdownHook(
-								new AEThread("MCGroup:VMShutdown")
+					}else{
+						try{
+								// set up group
+	
+							final MulticastSocket mc_sock = new MulticastSocket( group_port );
+	
+							mc_sock.setReuseAddress(true);
+	
+								// windows 98 doesn't support setTimeToLive
+	
+							try{
+								mc_sock.setTimeToLive(TTL);
+	
+							}catch( Throwable e ){
+	
+								if ( !ttl_problem_reported ){
+	
+									ttl_problem_reported	= true;
+	
+									adapter.log( e );
+								}
+							}
+		
+							adapter.trace( "group = " + group_address +"/" +
+											network_interface.getName()+":"+
+											network_interface.getDisplayName() + "-" + ni_address.getHostAddress() +": started" );
+	
+							mc_sock.joinGroup( group_address, network_interface );
+	
+							mc_sock.setNetworkInterface( network_interface );
+	
+								// note that false ENABLES loopback mode which is what we want
+	
+							mc_sock.setLoopbackMode(false);
+	
+							Runtime.getRuntime().addShutdownHook(
+									new AEThread("MCGroup:VMShutdown")
+									{
+										@Override
+										public void
+										runSupport()
+										{
+											try{
+												mc_sock.leaveGroup( group_address, network_interface );
+	
+											}catch( Throwable e ){
+	
+												adapter.log( e );
+											}
+										}
+									});
+	
+							new AEThread2("MCGroup:MCListener - " + ni_address, true )
 								{
 									@Override
 									public void
-									runSupport()
+									run()
 									{
-										try{
-											mc_sock.leaveGroup( group_address, network_interface );
-
-										}catch( Throwable e ){
-
-											adapter.log( e );
-										}
+										handleSocket( network_interface, ni_address, mc_sock, true );
 									}
-								});
-
-						new AEThread2("MCGroup:MCListener", true )
-							{
-								@Override
-								public void
-								run()
-								{
-									handleSocket( network_interface, ni_address, mc_sock, true );
-								}
-							}.start();
-
-					}catch( Throwable e ){
-
-						adapter.log( e );
+								}.start();
+	
+						}catch( Throwable e ){
+	
+							// adapter.log( "Failed to join group '" + group_address + ", ni=" + network_interface, e );
+						}
 					}
-
+					
 						// now do the incoming control listener
 
-					try{
-						final DatagramSocket control_socket = new DatagramSocket( null );
-
-						control_socket.setReuseAddress( true );
-
-						control_socket.bind( new InetSocketAddress(ni_address, control_port ));
-
-						if ( control_port == 0 ){
-
-							control_port	= control_socket.getLocalPort();
-
-							// System.out.println( "local port = " + control_port );
+					if ( USE_NIO ){
+						
+						try{
+							DatagramChannel control_channel = DatagramChannel.open( ipv6?StandardProtocolFamily.INET6:StandardProtocolFamily.INET );
+	
+							control_channel.setOption(StandardSocketOptions.SO_REUSEADDR, true );
+	
+							control_channel.bind( new InetSocketAddress(ni_address, control_port ));
+							
+							control_channel.socket().setSoTimeout( 30*1000 );
+							
+							if ( control_port == 0 ){
+	
+								control_port	= ((InetSocketAddress)control_channel.getLocalAddress()).getPort();
+	
+								// System.out.println( "local port = " + control_port );
+							}
+							
+							control_channel.configureBlocking( false );
+							
+							SelectorListener listener = new SelectorListener( network_interface, ni_address, control_channel, false );
+								
+							if ( ipv6 ){
+								
+								v6_selector.register( control_channel, listener, null );
+								
+							}else{ 
+								
+								v4_selector.register( control_channel, listener, null );
+							}
+						}catch( Throwable e ){
+	
+							adapter.log( e );
 						}
-
-						new AEThread2( "MCGroup:CtrlListener", true )
-							{
-								@Override
-								public void
-								run()
+					}else{
+				
+						try{
+							final DatagramSocket control_socket = new DatagramSocket( null );
+	
+							control_socket.setReuseAddress( true );
+	
+							control_socket.bind( new InetSocketAddress(ni_address, control_port ));
+	
+							if ( control_port == 0 ){
+	
+								control_port	= control_socket.getLocalPort();
+	
+								// System.out.println( "local port = " + control_port );
+							}
+	
+							new AEThread2( "MCGroup:CtrlListener - " + ni_address, true )
 								{
-									handleSocket( network_interface, ni_address, control_socket, false );
-								}
-							}.start();
-
-					}catch( Throwable e ){
-
-						adapter.log( e );
+									@Override
+									public void
+									run()
+									{
+										handleSocket( network_interface, ni_address, control_socket, false );
+									}
+								}.start();
+	
+						}catch( Throwable e ){
+	
+							adapter.log( e );
+						}
 					}
 				}
 			}
@@ -553,11 +618,6 @@ MCGroupImpl
 	sendToGroup(
 		final byte[]	data )
 	{
-		if ( instance_suspended ){
-
-			return;
-		}
-
 			// have debugs showing the send-to-group operation hanging and blocking AZ close, make async
 
 		async_dispatcher.dispatch(
@@ -586,6 +646,11 @@ MCGroupImpl
 					continue;
 				}
 
+				if ( ( ignore_v4 && !ipv6 ) || ( ignore_v6 && ipv6 )){
+					
+					continue;
+				}
+				
 				Enumeration<InetAddress> ni_addresses = network_interface.getInetAddresses();
 
 				String	socket_key = null;
@@ -593,8 +658,14 @@ MCGroupImpl
 				while( ni_addresses.hasMoreElements()){
 
 					InetAddress ni_address = ni_addresses.nextElement();
+					
+					if (	ipv6 && ni_address instanceof Inet4Address ||
+							!ipv6 && ni_address instanceof Inet6Address ){
 
-					if ( !( ni_address instanceof Inet6Address || ni_address.isLoopbackAddress())){
+						continue;
+					}
+					
+					if ( !ni_address.isLoopbackAddress()){
 
 						socket_key = ni_address.toString();
 
@@ -641,8 +712,12 @@ MCGroupImpl
 							socket_cache.put( socket_key, mc_sock );
 						}
 
-						// System.out.println( "sendToGroup: ni = " + network_interface.getName() + ", data = " + new String(data));
-
+						/*
+						if ( isIPv6() ){
+							System.out.println( "sendToGroup: ni = " + network_interface.getName() + ", data = " + new String(data));
+						}
+						*/
+						
 						DatagramPacket packet = new DatagramPacket(data, data.length, group_address.getAddress(), group_port );
 
 						try{
@@ -682,11 +757,6 @@ MCGroupImpl
 	sendToGroup(
 		final String	param_data )
 	{
-		if ( instance_suspended ){
-
-			return;
-		}
-
 			// have debugs showing the send-to-group operation hanging and blocking AZ close, make async
 
 		async_dispatcher.dispatch(
@@ -714,6 +784,11 @@ MCGroupImpl
 
 					continue;
 				}
+				
+				if ( ( ignore_v4 && !ipv6 ) || ( ignore_v6 && ipv6 )){
+					
+					continue;
+				}
 
 				Enumeration<InetAddress> ni_addresses = network_interface.getInetAddresses();
 
@@ -723,7 +798,13 @@ MCGroupImpl
 
 					InetAddress ni_address = ni_addresses.nextElement();
 
-					if ( !( ni_address instanceof Inet6Address || ni_address.isLoopbackAddress())){
+					if (	ipv6 && ni_address instanceof Inet4Address ||
+							!ipv6 && ni_address instanceof Inet6Address ){
+
+						continue;
+					}
+					
+					if ( !ni_address.isLoopbackAddress()){
 
 						an_address	= ni_address;
 
@@ -770,10 +851,16 @@ MCGroupImpl
 							socket_cache.put( socket_key, mc_sock );
 						}
 
-						byte[]	data = param_data.replaceAll("%AZINTERFACE%", an_address.getHostAddress()).getBytes();
-
-						// System.out.println( "sendToGroup: ni = " + network_interface.getName() + ", data = " + new String(data));
+						String host = AddressUtils.getHostAddressForURL(an_address);
+						
+						byte[]	data = param_data.replaceAll("%AZINTERFACE%", host).getBytes();
 
+						/*
+						if ( ipv6 ){
+							System.out.println( "sendToGroup: ni = " + network_interface.getName() + ", data = " + new String(data));
+						}
+						*/
+						
 						DatagramPacket packet = new DatagramPacket(data, data.length, group_address.getAddress(), group_port );
 
 						try{
@@ -831,22 +918,6 @@ MCGroupImpl
 
 		while(true){
 
-			if ( instance_suspended ){
-
-				try{
-					this_mon.enter();
-
-					if ( instance_suspended ){
-
-						suspended_threads.add( new Object[]{ Thread.currentThread().getName(), network_interface, local_address, socket, log_on_stop } );
-
-						return;
-					}
-				}finally{
-
-					this_mon.exit();
-				}
-			}
 			if ( !validNetworkAddress( network_interface, local_address )){
 
 				if ( log_on_stop ){
@@ -891,22 +962,111 @@ MCGroupImpl
 		}
 	}
 
+	class
+	SelectorListener
+		implements VirtualSelectorListener
+	{
+		private final NetworkInterface		network_interface;
+		private final InetAddress			local_address;
+		private final DatagramChannel		channel;
+		private final boolean				log_on_stop;
+		
+		long	successful_accepts 	= 0;
+		long	failed_accepts		= 0;
+
+		SelectorListener(
+			NetworkInterface	_network_interface,
+			InetAddress			_local_address,
+			DatagramChannel		_channel,
+			boolean				_log_on_stop )
+		{
+			network_interface		= _network_interface;
+			local_address			= _local_address;
+			channel 				= _channel;
+			log_on_stop				= _log_on_stop;
+		}
+		
+		@Override
+		public boolean 
+		selectSuccess(
+			VirtualAbstractChannelSelector	selector,
+			AbstractSelectableChannel 		sc, 
+			Object 							attachment )
+		{
+			if ( !validNetworkAddress( network_interface, local_address )){
+
+				if ( log_on_stop ){
+
+					adapter.trace(
+							"group = " + group_address +"/" +
+							network_interface.getName()+":"+
+							network_interface.getDisplayName() + " - " + local_address + ": stopped" );
+				}
+
+				selector.cancel( sc );
+				
+				return( false );
+			}
+			
+			try{
+				ByteBuffer buffer = ByteBuffer.allocate(PACKET_SIZE);
+
+				InetSocketAddress remote = (InetSocketAddress)channel.receive( buffer );
+								
+				successful_accepts++;
+
+				failed_accepts	 = 0;
+				
+				receivePacket( network_interface, local_address, buffer, remote );
+				
+				return( true );
+				
+			}catch( Throwable  e){
+				
+				failed_accepts++;
+
+				adapter.trace( "MCGroup: receive failed on port " + channel.socket().getLocalPort() + ":" + e.getMessage());
+
+				if (( failed_accepts > 100 && successful_accepts == 0 ) || failed_accepts > 1000 ){
+
+					adapter.trace( "    too many failures, abandoning" );
+
+					selector.cancel( sc );
+				}
+				
+				return( false );
+			}
+		}
+		
+		@Override
+		public void 
+		selectFailure(
+			VirtualAbstractChannelSelector	selector,
+			AbstractSelectableChannel		sc, 
+			Object							attachment, 
+			Throwable 						msg)
+		{
+			Debug.out( msg );
+			
+			selector.cancel( sc );
+		}
+	}
+	
 	private void
 	receivePacket(
 		NetworkInterface	network_interface,
 		InetAddress			local_address,
 	    DatagramPacket		packet )
 	{
-		if ( instance_suspended ){
-
-			return;
-		}
-
 		byte[]	data 	= packet.getData();
 		int		len		= packet.getLength();
 
-		// System.out.println( "receive: add = " + local_address + ", data = " + new String( data, 0, len ));
-
+		/*
+		if ( local_address instanceof Inet6Address ){
+			System.out.println( "receive: add = " + local_address + ", data = " + new String( data, 0, len ));
+		}
+		*/
+		
 		adapter.received(
 				network_interface,
 				local_address,
@@ -915,6 +1075,30 @@ MCGroupImpl
 				len );
 	}
 
+	private void
+	receivePacket(
+		NetworkInterface	network_interface,
+		InetAddress			local_address,
+		ByteBuffer			buffer,
+		InetSocketAddress	remote )
+	{
+		byte[]	data 	= buffer.array();
+		int		len		= buffer.position();
+
+		/*
+		if ( local_address instanceof Inet6Address ){
+			System.out.println( "receive: add = " + local_address + ", data = " + new String( data, 0, len ));
+		}
+		*/
+		
+		adapter.received(
+				network_interface,
+				local_address,
+				remote,
+				data,
+				len );
+	}
+	
 	@Override
 	public void
 	sendToMember(
@@ -923,15 +1107,14 @@ MCGroupImpl
 
 		throws MCGroupException
 	{
-		if ( instance_suspended ){
-
-			return;
-		}
-
 		DatagramSocket	reply_socket	= null;
 
-		// System.out.println( "sendToMember: add = " + address + ", data = " +new String( data ));
-
+		/*
+		if ( address.getAddress() instanceof Inet6Address ){
+			System.out.println( "sendToMember: add = " + address + ", data = " +new String( data ));
+		}
+		*/
+		
 		try{
 			reply_socket = new DatagramSocket( null );
 
