@@ -23,6 +23,9 @@ import java.io.ByteArrayOutputStream;
 import java.io.DataInputStream;
 import java.io.DataOutputStream;
 import java.io.IOException;
+import java.lang.reflect.InvocationHandler;
+import java.lang.reflect.Method;
+import java.lang.reflect.Proxy;
 import java.net.BindException;
 import java.net.DatagramPacket;
 import java.net.DatagramSocket;
@@ -36,6 +39,7 @@ import java.net.SocketTimeoutException;
 import java.nio.channels.UnsupportedAddressTypeException;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedList;
@@ -54,9 +58,12 @@ import com.biglybt.core.logging.LogIDs;
 import com.biglybt.core.logging.Logger;
 import com.biglybt.core.networkmanager.admin.NetworkAdmin;
 import com.biglybt.core.networkmanager.admin.NetworkAdminPropertyChangeListener;
+import com.biglybt.core.proxy.AEProxyFactory;
+import com.biglybt.core.proxy.AEProxyFactory.PluginProxy;
 import com.biglybt.core.stats.CoreStats;
 import com.biglybt.core.stats.CoreStatsProvider;
 import com.biglybt.core.util.AEMonitor;
+import com.biglybt.core.util.AENetworkClassifier;
 import com.biglybt.core.util.AEPriorityMixin;
 import com.biglybt.core.util.AESemaphore;
 import com.biglybt.core.util.AEThread2;
@@ -74,6 +81,7 @@ import com.biglybt.core.util.TimerEventPeriodic;
 import com.biglybt.net.udp.uc.PRUDPPacket;
 import com.biglybt.net.udp.uc.PRUDPPacketHandler;
 import com.biglybt.net.udp.uc.PRUDPPacketHandlerException;
+import com.biglybt.net.udp.uc.PRUDPPacketHandlerFactory;
 import com.biglybt.net.udp.uc.PRUDPPacketHandlerStats;
 import com.biglybt.net.udp.uc.PRUDPPacketReceiver;
 import com.biglybt.net.udp.uc.PRUDPPacketReply;
@@ -826,6 +834,16 @@ PRUDPPacketHandlerSupport
 
 				new_socket.setSoTimeout( 1000 );
 
+				try{
+					new_socket.setSendBufferSize( 4*1024*1024 );
+					
+					new_socket.setReceiveBufferSize( 4*1024*1024 );
+					
+				}catch( Throwable e ){
+					
+					Debug.out(e);
+				}
+				
 				Thread.currentThread().setName( "PRUDPPacketReciever:" + port + ":" + new_socket.getLocalAddress());
 				
 					// only make the socket public once fully configured
@@ -1860,6 +1878,11 @@ PRUDPPacketHandlerSupport
 			}
 			*/
 			
+			if ( Constants.isCVSVersion() &&  e instanceof IndexOutOfBoundsException ){
+				
+				Debug.out( e );
+			}
+			
 			Logger.log(new LogEvent(LOGID, LogEvent.LT_ERROR, "PRUDPPacketHandler: send to " + destination_address + " failed: " + Debug.getNestedExceptionMessage(e)));
 
 			throw( new PRUDPPacketHandlerException( "PRUDPPacketHandler:send failed", e ));
@@ -2058,10 +2081,37 @@ PRUDPPacketHandlerSupport
 	@Override
 	public PRUDPPacketHandler
 	openSession(
-		InetSocketAddress		target )
+		InetSocketAddress		target,
+		String[]				networks,
+		String					reason )
 
 		throws PRUDPPacketHandlerException
 	{
+		if ( AENetworkClassifier.categoriseAddress( target ) == AENetworkClassifier.AT_I2P ){
+			
+			Map<String,Object> opts = new HashMap<>();
+			
+			if ( networks != null ){
+				
+				opts.put( AEProxyFactory.PO_PEER_NETWORKS, networks );
+			}
+			
+			opts.put( AEProxyFactory.PO_PROTOCOL, AEProxyFactory.PO_PROTOCOL_UDP );
+			
+			PluginProxy pp = AEProxyFactory.getPluginProxy( reason, target.getHostString(), target.getPort(), opts );
+			
+			if ( pp != null ){
+				
+				try{
+					return( new PRUDPPacketHandlerPluginProxy( this, target, pp ));
+					
+				}catch( Throwable e ){
+					
+					pp.setOK( true );
+				}
+			}
+		}
+		
 		if ( use_socks ){
 
 			return( new PRUDPPacketHandlerSocks( target ));
