@@ -19,6 +19,7 @@
 
 package com.biglybt.net.upnp;
 
+import java.net.InetAddress;
 import java.util.Map;
 
 /**
@@ -39,9 +40,18 @@ UPnPActionInvocation
 		 * @throws UPnPException
 		 */
 
-	public UPnPActionArgument[]
+	public default UPnPActionArgument[]
 	invoke()
 
+		throws UPnPException
+	{
+		return( invoke( null ));
+	}
+	
+	public UPnPActionArgument[]
+	invoke(
+		InetAddress		bind )
+
 		throws UPnPException;
 
 	public Map
