@@ -28,6 +28,8 @@ import java.io.*;
 import java.net.*;
 import java.util.*;
 
+import com.biglybt.core.devices.impl.DeviceManagerImpl;
+import com.biglybt.core.networkmanager.admin.NetworkAdmin;
 import com.biglybt.core.proxy.AEProxySelectorFactory;
 import com.biglybt.core.util.*;
 import com.biglybt.net.upnp.*;
@@ -92,7 +94,7 @@ UPnPImpl
 
 	private AsyncDispatcher		async_dispatcher = new AsyncDispatcher();
 
-	private ThreadPool	device_dispatcher	 = new ThreadPool("UPnPDispatcher", 1, true );
+	private ThreadPool<AERunnable>	device_dispatcher	 = new ThreadPool<>("UPnPDispatcher", 1, true );
 	private Set			device_dispatcher_pending	= new HashSet();
 
 	private Map<String,long[]>	failed_urls = new HashMap<>();
@@ -214,19 +216,18 @@ UPnPImpl
 
 						if ( !old_root_device.getNetworkInterface().getName().equals( network_interface.getName())){
 
-							if ( old_root_device.addAlternativeLocation( location )){
+							old_root_device.addAlternativeLocation( local_address, location );
 
-								log( "Adding alternative location " +location + " to " + usn );
+							return;
+							
+						}else{
+							
+								// check that the device's location is the same
+					
+							if ( old_root_device.checkSameLocation( local_address, location )){
+									
+								return;
 							}
-
-							return;
-						}
-
-							// check that the device's location is the same
-
-						if ( old_root_device.getLocation().equals( location )){
-
-							return;
 						}
 					}
 
@@ -250,12 +251,12 @@ UPnPImpl
 						old_root_device.destroy( true );
 					}
 
-					List	listeners;
+					List<UPnPListener>	listeners;
 
 					try{
 						rd_listeners_mon.enter();
 
-						listeners = new ArrayList( rd_listeners );
+						listeners = new ArrayList<>( rd_listeners );
 
 					}finally{
 
@@ -286,24 +287,61 @@ UPnPImpl
 
 							root_locations.put( usn, new_root_device );
 
-							listeners = new ArrayList( rd_listeners );
+							listeners = new ArrayList<>( rd_listeners );
 
 						}finally{
 
 							rd_listeners_mon.exit();
 						}
 
-						for (int i=0;i<listeners.size();i++){
-
-							try{
-								((UPnPListener)listeners.get(i)).rootDeviceFound( new_root_device );
-
-							}catch( Throwable e ){
-
-								Debug.printStackTrace(e);
+							// We have an issue regarding the same device being discovered via IPv4 and IPv6.
+							// Some operations have a preferred IP family (pinholes being added over IPv6...) but
+							// if we discover it over IPv4 first then it may fail whereas once the IPv6 route is discovered
+							// it will work. Of course we may never discover it over V6, or the V6 discovery might happen
+							// a lot later. The easiest fix is to defer the discovery for a bit in the hope that the
+							// "other" discovery occurs in a timely manner...
+						
+						NetworkAdmin na = NetworkAdmin.getSingleton();
+						
+						if ( na.hasIPV4Potential() && na.hasIPV6Potential()){
+							
+							List<UPnPListener>	f_listeners = listeners;
+							
+							new DelayedEvent(
+									"Delay:rootDeviceFound", 
+									2500,
+									new AERunnable()
+									{
+										@Override
+										public void
+										runSupport()
+										{
+											for (int i=0;i<f_listeners.size();i++){
+												
+												try{
+													((UPnPListener)f_listeners.get(i)).rootDeviceFound( new_root_device );
+					
+												}catch( Throwable e ){
+					
+													Debug.printStackTrace(e);
+												}
+											}
+										}
+									});
+							
+						}else{
+							
+							for (int i=0;i<listeners.size();i++){
+	
+								try{
+									((UPnPListener)listeners.get(i)).rootDeviceFound( new_root_device );
+	
+								}catch( Throwable e ){
+	
+									Debug.printStackTrace(e);
+								}
 							}
 						}
-
 					}catch( UPnPException e ){
 
 						String	message = e.getMessage();
@@ -362,7 +400,7 @@ UPnPImpl
 						return;
 					}
 
-					log( "UPnP: root lost: usn=" + usn + ", location=" + root_device.getLocation() + ", ni=" + root_device.getNetworkInterface().getName() + ",local=" + root_device.getLocalAddress().toString());
+					log( "UPnP: root lost: usn=" + usn + ", location=" + root_device.getLocation() + ", ni=" + root_device.getNetworkInterface().getName() + ",local=" + root_device.getLocalAddress(true) + "/" + root_device.getLocalAddress(false));
 
 					root_device.destroy( false );
 				}
@@ -724,9 +762,10 @@ UPnPImpl
 
 	public SimpleXMLParserDocument
 	performSOAPRequest(
-		UPnPService service,
+		UPnPService 	service,
 		String			soap_action,
-		String			request )
+		String			request,
+		InetAddress		bind )
 
 		throws SimpleXMLParserDocumentException, UPnPException, IOException
 	{
@@ -734,18 +773,18 @@ UPnPImpl
 
 		if ( service.getDirectInvocations() || forceDirect()){
 
-			res = performSOAPRequest( service, soap_action, request, false );
+			res = performSOAPRequest( service, soap_action, request, false, bind );
 
 		}else{
 
 			try{
-				res =  performSOAPRequest( service, soap_action, request, true );
+				res =  performSOAPRequest( service, soap_action, request, true, bind );
 
 				http_calls_ok++;
 
 			}catch( IOException e ){
 
-				res = performSOAPRequest( service, soap_action, request, false );
+				res = performSOAPRequest( service, soap_action, request, false, bind );
 
 				direct_calls_ok++;
 
@@ -768,26 +807,47 @@ UPnPImpl
 		UPnPService		service,
 		String			soap_action,
 		String			request,
-		boolean			use_http_connection)
+		boolean			use_http_connection,
+		InetAddress		bind )
 
 		throws SimpleXMLParserDocumentException, UPnPException, IOException
 	{
 		//long	start = SystemTime.getMonotonousTime();
 
-		List<URL>	controls = service.getControlURLs();
+		List<URL>	controls = service.getControlURLs( bind == null || ( bind instanceof Inet4Address ));
 
 		Throwable last_error = null;
 
 		for ( URL control: controls ){
 
+			boolean do_bind = bind != null;
+			
+			if ( do_bind ){
+				
+				do_bind = false;
+				
+					// only implement this for IPv6 as it is unlikely that we have multiple IPv4
+					// addresses whereas with "privacy IPv6" it is likely that we have > 1
+				
+				try{
+					InetAddress ta = InetAddress.getByName( control.getHost());
+					
+					if ( ta instanceof Inet6Address && bind instanceof Inet6Address ){
+							
+						do_bind = true;
+					}
+				}catch( Throwable e ){
+				}
+			}
+			
 			boolean	good_url = true;
 
 			try{
 				adapter.trace( "UPnP:Request: -> " + control + "," + request );
 
-				if ( use_http_connection ){
+				if ( use_http_connection && !do_bind ){
 
-					try{
+					try{							
 						AEProxySelectorFactory.getSelector().startNoProxy();
 
 						TorrentUtils.setTLSDescription( "UPnP Device: " + service.getDevice().getFriendlyName());
@@ -820,6 +880,7 @@ UPnPImpl
 								// gotta retry with M-POST method
 
 							try{
+								
 								HttpURLConnection con2 = (HttpURLConnection)control.openConnection();
 
 								con2.setRequestProperty( "Content-Type", "text/xml; charset=\"utf-8\"" );
@@ -878,13 +939,26 @@ UPnPImpl
 
 						AEProxySelectorFactory.getSelector().endNoProxy();
 					}
-				}else{
+				}	else{
 					final int CONNECT_TIMEOUT 	= 15*1000;
 					final int READ_TIMEOUT		= 30*1000;
 
 					Socket	socket = new Socket( Proxy.NO_PROXY );
 
-					socket.connect( new InetSocketAddress( control.getHost(), control.getPort()), CONNECT_TIMEOUT );
+					InetSocketAddress target = new InetSocketAddress( control.getHost(), control.getPort());
+					
+					if ( do_bind ){
+						
+						try{
+							socket.bind( new InetSocketAddress( bind, 0 ));
+							
+						}catch( Throwable e ){
+								
+							Debug.out( e );
+						}
+					}
+					
+					socket.connect( target, CONNECT_TIMEOUT );
 
 					socket.setSoTimeout( READ_TIMEOUT );
 
