@@ -377,6 +377,17 @@ DownloadImpl
 		}
 	}
 
+	
+	@Override
+	public void setStartReason(String reason) {
+		setUserData( UD_KEY_START_REASON, reason );
+	}
+
+	@Override
+	public String getStartReason() {
+		return((String)getUserData( UD_KEY_START_REASON ));
+	}
+	
 	@Override
 	public void setStopReason(String reason) {
 		setUserData( UD_KEY_STOP_REASON, reason );
@@ -387,6 +398,16 @@ DownloadImpl
 		return((String)getUserData( UD_KEY_STOP_REASON ));
 	}
 
+	@Override
+	public void setQueueReason(String reason) {
+		setUserData( UD_KEY_QUEUE_REASON, reason );
+	}
+
+	@Override
+	public String getQueueReason() {
+		return((String)getUserData( UD_KEY_QUEUE_REASON ));
+	}
+	
 	@Override
 	public void
 	stopAndQueue()
@@ -1556,6 +1577,13 @@ DownloadImpl
 							return( details );
 						}
 		
+						@Override
+						public String 
+						getDetails()
+						{
+							return( getName());
+						}
+						
 						@Override
 						public int
 						getSeedCount()
@@ -1668,6 +1696,46 @@ DownloadImpl
 	{
 		String class_name = getTrackingName( result );
 
+		String plugin_id;
+		
+		if ( class_name == null ){
+			
+			plugin_id = "azbpdhdtracker";
+			
+		}else{
+			
+			if ( class_name.equalsIgnoreCase( "I2P" )){
+				
+				plugin_id = "azneti2phelper";
+				
+			}else{
+				
+				plugin_id = class_name;
+			}
+		}
+		
+		boolean skip_announce = false;
+		
+		if ( plugin_id != null ){
+			
+			Map all_opts = download_manager.getDownloadState().getMapAttribute( DownloadManagerState.AT_PLUGIN_OPTIONS );
+			
+			if ( all_opts != null ){
+				
+				Map opts = (Map)all_opts.get( plugin_id.toLowerCase( Locale.US ));
+				
+				if ( opts != null ){
+					
+					Number e = (Number)opts.get( DownloadManagerState.AT_PO_ENABLE_ANNOUNCE );
+					
+					if ( e != null && e.intValue() == 0 ){
+						
+						skip_announce = true;
+					}
+				}
+			}
+		}
+		
 		boolean new_entry = false;
 		
 		if ( class_name != null ){
@@ -1718,7 +1786,10 @@ DownloadImpl
 			}
 		}
 
-		download_manager.setAnnounceResult( result );
+		if ( !skip_announce ){
+		
+			download_manager.setAnnounceResult( result );
+		}
 		
 		if ( new_entry ){
 			
