@@ -438,6 +438,16 @@ RPDownload
 		}
 	}
 
+	@Override
+	public void setStartReason(String reason) {
+		setUserData( UD_KEY_START_REASON, reason );
+	}
+
+	@Override
+	public String getStartReason() {
+		return((String)getUserData( UD_KEY_START_REASON ));
+	}
+	
 	@Override
 	public void setStopReason(String reason) {
 		setUserData( UD_KEY_STOP_REASON, reason );
@@ -448,6 +458,16 @@ RPDownload
 		return((String)getUserData( UD_KEY_STOP_REASON ));
 	}
 
+	@Override
+	public void setQueueReason(String reason) {
+		setUserData( UD_KEY_QUEUE_REASON, reason );
+	}
+
+	@Override
+	public String getQueueReason() {
+		return((String)getUserData( UD_KEY_QUEUE_REASON ));
+	}
+	
 	@Override
 	public void
 	restart()
