@@ -22,7 +22,6 @@ import java.util.regex.Pattern;
 
 import com.biglybt.core.internat.IntegratedResourceBundle;
 import com.biglybt.core.internat.MessageText;
-import com.biglybt.core.logging.LogIDs;
 import com.biglybt.core.util.Constants;
 import com.biglybt.core.util.Debug;
 import com.biglybt.core.util.RegExUtil;
@@ -48,8 +47,6 @@ import com.biglybt.ui.swt.Utils;
 public class SkinPropertiesImpl
 	implements SkinProperties
 {
-	private static final LogIDs LOGID = LogIDs.UI3;
-
 	private static final boolean DARK_MODE = Utils.isDarkAppearanceNative();
 
 	public static final String PATH_SKIN_DEFS = "com/biglybt/ui/skin/";
