@@ -172,7 +172,7 @@ public class MainStatusBar
 
 	private String lastSRimageID = null;
 
-	private int last_dl_limit;
+	private long last_dl_limit;
 
 	private long last_rec_data = - 1;
 
@@ -1383,8 +1383,17 @@ public class MainStatusBar
 			GlobalManagerStats stats = gm.getStats();
 
 			int kinb = DisplayFormatters.getKinB();
+			int base = DisplayFormatters.getXinBBase();
 			
-			int dl_limit = NetworkManager.getMaxDownloadRateBPS() / kinb;
+			char K_str = DisplayFormatters.getUnit(DisplayFormatters.UNIT_KB ).charAt(0);
+			char M_str = DisplayFormatters.getUnit(DisplayFormatters.UNIT_MB ).charAt(0);
+			
+			char D_str = K_str;
+			long dl_limit = NetworkManager.getMaxDownloadRateBPS() / kinb;
+			if ( dl_limit > kinb * base){
+				dl_limit /= kinb;
+				D_str = M_str;
+			}
 			long rec_data = stats.getDataReceiveRate();
 			long rec_prot = stats.getProtocolReceiveRate();
 
@@ -1393,36 +1402,45 @@ public class MainStatusBar
 				last_rec_data = rec_data;
 				last_rec_prot = rec_prot;
 
-				statusDown.setText((dl_limit == 0 ? "" : "[" + dl_limit + "K] ")
+				statusDown.setText((dl_limit == 0 ? "" : "[" + dl_limit + D_str +"] ")
 						+ DisplayFormatters.formatDataProtByteCountToKiBEtcPerSec(rec_data, rec_prot));
 			}
 
 			boolean auto_up = TransferSpeedValidator.isAutoSpeedActive(gm)
 					&& TransferSpeedValidator.isAutoUploadAvailable(core);
 
-			int ul_limit_norm = NetworkManager.getMaxUploadRateBPSNormal() / kinb;
+			long ul_limit_norm = NetworkManager.getMaxUploadRateBPSNormal() / kinb;
 
 			String seeding_only;
 			if (NetworkManager.isSeedingOnlyUploadRate()) {
-				int ul_limit_seed = NetworkManager.getMaxUploadRateBPSSeedingOnly() / kinb;
+				long ul_limit_seed = NetworkManager.getMaxUploadRateBPSSeedingOnly() / kinb;
 				if (ul_limit_seed == 0) {
-					seeding_only = "+" + Constants.INFINITY_STRING + "K";
+					seeding_only = "+" + Constants.INFINITY_STRING + K_str;
 				} else {
-					int diff = ul_limit_seed - ul_limit_norm;
-					seeding_only = (diff >= 0 ? "+" : "") + diff + "K";
+					long diff = ul_limit_seed - ul_limit_norm;
+					char X_str = K_str;
+					if ( diff > kinb * base ){
+						diff /= kinb;
+						X_str = M_str;
+					}
+					seeding_only = (diff >= 0 ? "+" : "") + diff + X_str;
 				}
 			} else {
 				seeding_only = "";
 			}
 
-			int sent_data = stats.getDataSendRate();
+			long sent_data = stats.getDataSendRate();
 			if (imgRec != null && !imgRec.isDisposed()) {
 				updateGraph(statusDown, imgRec, rec_data, max_rec);
 				updateGraph(statusUp, imgSent, sent_data, max_sent);
 			}
 
-
-			statusUp.setText((ul_limit_norm == 0 ? "" : "[" + ul_limit_norm + "K"
+			char U_str = K_str;
+			if ( ul_limit_norm > kinb * base ){
+				ul_limit_norm /= kinb;
+				U_str = M_str;
+			}
+			statusUp.setText((ul_limit_norm == 0 ? "" : "[" + ul_limit_norm + U_str
 					+ seeding_only + "]")
 					+ (auto_up ? "* " : " ")
 					+ DisplayFormatters.formatDataProtByteCountToKiBEtcPerSec(
@@ -1801,6 +1819,9 @@ public class MainStatusBar
 
 		private Image bgImage;
 
+		private String lastTextComputed;
+		private Point lastTextSizeComputed;
+		
 		/**
 		 * Default Constructor
 		 *
@@ -1967,13 +1988,25 @@ public class MainStatusBar
 				lastSize.y = bounds.height;
 			}
 
-			GC gc = new GC(this);
-			GCStringPrinter sp = new GCStringPrinter(gc, getText(), new Rectangle(0,
-					0, 10000, 20), true, true, SWT.LEFT);
-			sp.calculateMetrics();
-			Point lastTextSize = sp.getCalculatedSize();
-			gc.dispose();
-
+			Point lastTextSize;
+			
+			String text = getText();
+			
+			if ( lastTextComputed != null && lastTextComputed.equals( text )){
+				
+				lastTextSize = lastTextSizeComputed;
+			}else{
+				GC gc = new GC(this);
+				GCStringPrinter sp = new GCStringPrinter(gc, text, new Rectangle(0,
+						0, 10000, 20), true, true, SWT.LEFT);
+				sp.calculateMetrics();
+				lastTextSize = sp.getCalculatedSize();
+				gc.dispose();
+				
+				lastTextComputed		= text;
+				lastTextSizeComputed	= lastTextSize;
+			}
+			
 			lastSize.x += lastTextSize.x + 10;
 			lastSize.y = Math.max(lastSize.y, lastTextSize.y);
 
