@@ -203,6 +203,11 @@ public abstract class BaseMDI
 		if (entry == null) {
 			return null;
 		}
+		if (( entry instanceof BaseMdiEntry ) && !((BaseMdiEntry)entry).canClose( userInitiated )){
+		
+			return( null );
+		}
+		
 		return closeEntryByID(entry.getViewID(), userInitiated );
 	}
 	
@@ -233,7 +238,7 @@ public abstract class BaseMDI
 		}
 		
 		if (currentEntry == removedItem) {
-			setCurrentEntry(null);
+			setSelectedEntry(null);
 		}
 
 		removedItem.closeView( userInitiated );
@@ -294,15 +299,15 @@ public abstract class BaseMDI
 	                                                boolean closeable, String preferedAfterID);
 
 	@Override
-	public MdiEntrySWT getCurrentEntry() {
+	public MdiEntrySWT getSelectedEntry() {
 		if (isDisposed()) {
 			return null;
 		}
 		return currentEntry;
 	}
-
+	
 	protected void
-	setCurrentEntry(
+	setSelectedEntry(
 		MdiEntrySWT		entry )
 	{
 		currentEntry = entry;
@@ -686,7 +691,7 @@ public abstract class BaseMDI
 
 	@Override
 	public void updateUI() {
-		MdiEntry currentEntry = getCurrentEntry();
+		MdiEntry currentEntry = getSelectedEntry();
 		if (currentEntry != null) {
 			currentEntry.updateUI( false );
 		}
@@ -754,6 +759,7 @@ public abstract class BaseMDI
 				builder = vi.getBuilder(getDataSourceType(), id);
 			}
 			if (builder != null) {
+				builder.setInitialDatasource(datasource);
 				mdiEntry = createEntry(builder, true);
 			}
 		}
