@@ -19,6 +19,7 @@
 package com.biglybt.ui.swt.subscriptions;
 
 
+import java.text.SimpleDateFormat;
 import java.util.*;
 import java.util.List;
 import java.util.function.Function;
@@ -37,6 +38,7 @@ import com.biglybt.core.internat.MessageText;
 import com.biglybt.core.subs.Subscription;
 import com.biglybt.core.subs.SubscriptionDownloadListener;
 import com.biglybt.core.subs.SubscriptionException;
+import com.biglybt.core.subs.SubscriptionHistory;
 import com.biglybt.core.subs.SubscriptionListener;
 import com.biglybt.core.subs.SubscriptionResult;
 import com.biglybt.core.subs.SubscriptionResultFilter;
@@ -187,7 +189,9 @@ SBC_SubscriptionResultsView
 				}
 			}
 		}
-				
+			
+		SWTSkinObjectText info;
+		
 		if ( ds != null ){
 
 			if (( ds.getViewOptions() & Subscription.VO_HIDE_HEADER) != 0 ){
@@ -231,6 +235,12 @@ SBC_SubscriptionResultsView
 						}
 					});
 			}
+			
+			info = (SWTSkinObjectText) getSkinObject("topinfo");
+			
+		}else{
+			
+			info = null;
 		}
 
 		final SWTSkinObject soFilterArea = getSkinObject("filterarea");
@@ -310,6 +320,46 @@ SBC_SubscriptionResultsView
 								return;
 							}
 							
+							if ( info != null ){
+																
+								SubscriptionHistory history = ds.getHistory();
+								
+								String error = history.getLastError();
+
+								boolean isError = error != null && !error.isEmpty();
+											
+								String lastUpdate;
+								
+								if ( isError ){
+									
+									lastUpdate = MessageText.getString( "ManagerItem.error" ) + " (" + DisplayFormatters.formatDateYMDHM( ds.getHistory().getLastErrorTime()) + ")";
+								}else{
+									
+									lastUpdate = DisplayFormatters.formatDateYMDHM( history.getLastScanTime());
+								}
+								
+								long next = history.getNextScanTime();
+								
+								long nextScheduled = history.getNextScheduledUpdate();
+								
+								if ( nextScheduled > 0 ){
+									
+									next = nextScheduled;
+								}
+								
+								info.setText( 
+										MessageText.getString( "Trackers.column.last_update" ) + ": " + lastUpdate + ", " +
+										MessageText.getString( "Button.next" ) + ": " + DisplayFormatters.formatDateYMDHM( next ));
+								
+								
+								if ( !isError ){
+									
+									error = MessageText.getString( "label.none" );
+								}
+								
+								Utils.setTT( info.getControl(), MessageText.getString( "subs.prop.last_error" ) + ": " + error );
+							}
+							
 							List<Subscription> deps = ds_filter.getDependsOn();
 							
 							if ( deps != null && !deps.isEmpty()){
@@ -1178,7 +1228,7 @@ SBC_SubscriptionResultsView
 		Subscription		subs,
 		int					reason )
 	{
-		if ( reason == CR_RESULTS){
+		if ( reason == CR_RESULTS ){
 
 			TableViewSWT<SubscriptionResultFilterable> tv = tv_subs_results;
 					
@@ -1194,7 +1244,10 @@ SBC_SubscriptionResultsView
 						}
 					});
 			}
-		}else if ( reason == CR_METADATA ){
+		}
+		
+		
+		if ( reason == CR_METADATA || reason == CR_RESULTS ){
 			
 			if ( pFilterUpdater != null ){
 				
@@ -1203,7 +1256,6 @@ SBC_SubscriptionResultsView
 					pFilterUpdater.run();
 				});
 			}
-
 		}
 	}
 
@@ -1280,6 +1332,14 @@ SBC_SubscriptionResultsView
 
 			initTable((Composite) so_list.getControl());
 		}
+		
+		if ( pFilterUpdater != null ){
+			
+			Utils.execSWTThread(()->{
+				
+				pFilterUpdater.run();
+			});
+		}
 	}
 
 	private void
@@ -1300,6 +1360,8 @@ SBC_SubscriptionResultsView
 			}
 		}
 
+		col_filter_helper = null;
+		
 		Utils.disposeSWTObjects(new Object[] {
 			table_parent,
 		});
