@@ -913,7 +913,7 @@ public class ToolBarView
 
 		if (mdi != null) {
 			UIToolBarItem[] allToolBarItems = tbm.getAllToolBarItems();
-			MdiEntrySWT entry = mdi.getCurrentEntry();
+			MdiEntrySWT entry = mdi.getSelectedEntry();
 			Map<String, Long> mapStates = new HashMap<>();
 			if (entry != null) {
 				UIToolBarEnablerBase[] enablers = entry.getToolbarEnablers();
@@ -1194,7 +1194,7 @@ public class ToolBarView
 		}
 		MultipleDocumentInterfaceSWT mdi = UIFunctionsManagerSWT.getUIFunctionsSWT().getMDISWT();
 		if (mdi != null) {
-			MdiEntrySWT entry = mdi.getCurrentEntry();
+			MdiEntrySWT entry = mdi.getSelectedEntry();
 			if ( entry != null ){
 				UIToolBarEnablerBase[] enablers = entry.getToolbarEnablers();
 				for (UIToolBarEnablerBase enabler : enablers) {
