@@ -53,7 +53,7 @@ import com.biglybt.pif.ui.menus.MenuManager;
 import com.biglybt.pif.ui.tables.*;
 
 public abstract class TableViewSWT_Common
-	implements MouseListener, MouseMoveListener, SelectionListener, KeyListener, MenuDetectListener
+	implements MouseListener, MouseMoveListener, MouseTrackListener, SelectionListener, KeyListener, MenuDetectListener
 {
 
 	TableViewSWT<?> tv;
@@ -462,6 +462,16 @@ public abstract class TableViewSWT_Common
 		}
 	}
 
+	@Override
+	public void mouseEnter(MouseEvent e){
+	}
+	@Override
+	public void mouseExit(MouseEvent e){
+	}
+	@Override
+	public void mouseHover(MouseEvent e){
+	}
+	
 	@Override
 	public void widgetSelected(SelectionEvent e) {
 	}
@@ -1322,13 +1332,13 @@ public abstract class TableViewSWT_Common
 		int originalHeight = tv.getRowDefaultHeight();
 		SpeedScaleShell optionShell = new SpeedScaleShell() {
 			@Override
-			public void setValue(int value) {
+			public void setValue(long value) {
 				super.setValue(value);
-				Utils.execSWTThreadLater(100, () -> tv.setRowHeight(getValue()));
+				Utils.execSWTThreadLater(100, () -> tv.setRowHeight((int)getValue()));
 			}
 
 			@Override
-			public String getStringValue(int value, String sValue) {
+			public String getStringValue(long value, String sValue) {
 				if (sValue != null) {
 					return sValue;
 				}
@@ -1345,7 +1355,7 @@ public abstract class TableViewSWT_Common
 					}), i * lineHeight + 2);
 		}
 		if (optionShell.open(null, tv.getRowDefaultHeight(), false)) {
-			tv.setRowHeight(optionShell.getValue());
+			tv.setRowHeight((int)optionShell.getValue());
 		} else {
 			tv.setRowHeight(originalHeight);
 		}
