@@ -28,7 +28,6 @@ import com.biglybt.pif.download.DownloadTypeComplete;
 import com.biglybt.pif.download.DownloadTypeIncomplete;
 import com.biglybt.pif.ui.tables.TableColumn;
 import com.biglybt.pif.ui.tables.TableColumnCreationListener;
-import com.biglybt.ui.swt.plugin.net.buddy.swt.columns.ColumnChatStatus;
 import com.biglybt.ui.swt.views.columnsetup.ColumnTC_ChosenColumn;
 import com.biglybt.ui.swt.views.columnsetup.ColumnTC_NameInfo;
 import com.biglybt.ui.swt.views.columnsetup.ColumnTC_Sample;
@@ -261,6 +260,7 @@ public class TableColumnCreator
 		c.put(TagAddedToDateItem.COLUMN_ID, new cInfo(TagAddedToDateItem.class, TagAddedToDateItem.DATASOURCE_TYPE));
 		c.put(TagSortItem.COLUMN_ID, new cInfo(TagSortItem.class, TagSortItem.DATASOURCE_TYPE));
 		c.put(NetworksItem.COLUMN_ID, new cInfo(NetworksItem.class, NetworksItem.DATASOURCE_TYPE));
+		c.put(NetworksIconsItem.COLUMN_ID, new cInfo(NetworksIconsItem.class, NetworksIconsItem.DATASOURCE_TYPE));
 		c.put(PeerSourcesItem.COLUMN_ID, new cInfo(PeerSourcesItem.class, PeerSourcesItem.DATASOURCE_TYPE));
 		c.put(AvailabilityItem.COLUMN_ID, new cInfo(AvailabilityItem.class, AvailabilityItem.DATASOURCE_TYPE));
 		c.put(AvgAvailItem.COLUMN_ID, new cInfo(AvgAvailItem.class, AvgAvailItem.DATASOURCE_TYPE));
